pub struct AddPostings;Expand description
Add Postings operation
Adds a collection of document postings to the index. The index must already be initialized in the context.
Context Requirements
- Context must have an initialized index
- All postings must have consistent vector dimensions
Example
use shardex::api::{ShardexContext, AddPostingsParams, CreateIndexParams};
use shardex::api::operations::{AddPostings, CreateIndex};
use shardex::{Posting, DocumentId};
use apithing::ApiOperation;
let postings = vec![
Posting {
document_id: DocumentId::from_raw(1),
start: 0,
length: 100,
vector: vec![0.1; 384],
}
];
let params = AddPostingsParams::new(postings)?;
AddPostings::execute(&mut context, ¶ms)?;Trait Implementations
Sourceimpl ApiOperation<ShardexContext, AddPostingsParams> for AddPostings
impl ApiOperation<ShardexContext, AddPostingsParams> for AddPostings
Sourcetype Error = ShardexError
type Error = ShardexError
The error type returned when an operation fails.
Sourcefn execute(
context: &mut ShardexContext,
parameters: &AddPostingsParams,
) -> Result<Self::Output, Self::Error>
fn execute( context: &mut ShardexContext, parameters: &AddPostingsParams, ) -> Result<Self::Output, Self::Error>
Execute the API operation with the given context and properties.