GetDocumentText

Struct GetDocumentText 

pub struct GetDocumentText;
Get Document Text operation

Retrieves the full text content of a document by its ID. The document must have been stored with text storage enabled.

Context Requirements

  • Context must have an initialized index
  • Index must be configured with text storage enabled
  • Document must exist in the index

Example

use shardex::api::{ShardexContext, GetDocumentTextParams};
use shardex::api::operations::GetDocumentText;
use shardex::{DocumentId};
use apithing::ApiOperation;

let doc_id = DocumentId::from_raw(1);
let params = GetDocumentTextParams::new(doc_id);

// let text = GetDocumentText::execute(&mut context, &params)?;
// println!("Document text: {}", text);