pub struct GetPerformanceStats;Expand description
Get Performance Stats operation
Retrieves current performance statistics from the system, with optional detailed metrics including operation breakdowns and timing information.
Context Requirements
- Context must have an initialized index (for basic stats)
- Performance monitoring may need to be enabled for detailed metrics
Example
use shardex::api::{ShardexContext, GetPerformanceStatsParams, CreateIndexParams};
use shardex::api::operations::{GetPerformanceStats, CreateIndex};
use apithing::ApiOperation;
let params = GetPerformanceStatsParams::detailed();
let stats = GetPerformanceStats::execute(&mut context, ¶ms)?;
println!("Total operations: {}, Memory: {} MB",
stats.total_operations,
stats.memory_usage / 1024 / 1024);Trait Implementations
Sourceimpl ApiOperation<ShardexContext, GetPerformanceStatsParams> for GetPerformanceStats
impl ApiOperation<ShardexContext, GetPerformanceStatsParams> for GetPerformanceStats
Sourcetype Output = PerformanceStats
type Output = PerformanceStats
The type returned by a successful operation execution.
Sourcetype Error = ShardexError
type Error = ShardexError
The error type returned when an operation fails.
Sourcefn execute(
context: &mut ShardexContext,
parameters: &GetPerformanceStatsParams,
) -> Result<Self::Output, Self::Error>
fn execute( context: &mut ShardexContext, parameters: &GetPerformanceStatsParams, ) -> Result<Self::Output, Self::Error>
Execute the API operation with the given context and properties.