ValidateConfigParams

Struct ValidateConfigParams 

pub struct ValidateConfigParams {
    pub config: ShardexConfig,
}
Parameters for validating a ShardexConfig

Contains a ShardexConfig to be validated without creating or opening an index. This is useful for testing configuration validity before performing operations.

Fields

config: ShardexConfig

The configuration to validate

Implementations

Source

impl ValidateConfigParams

pub fn new(config: ShardexConfig) -> Self

Create new validate config parameters

Arguments
  • config - The ShardexConfig to validate
Example
use shardex::api::parameters::ValidateConfigParams;
use shardex::ShardexConfig;

let config = ShardexConfig::new().vector_size(384).shard_size(10000);
let params = ValidateConfigParams::new(config);
assert_eq!(params.config.vector_size, 384);
pub fn validate(&self) -> Result<(), ShardexError>

Validate the parameters

This validates the contained ShardexConfig and always succeeds for ValidateConfigParams itself (the config validation is the operation).

Errors

Returns ShardexError::Config if the contained configuration is invalid.

pub fn get_config(&self) -> &ShardexConfig

Get a reference to the configuration